==> nextcloud-31.0.3-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/serverinfo/l10n/es.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "Información de CPU no disponible",
    "CPU Usage:" : "Uso de CPU:",
    "Load average: {percentage} % ({load}) last minute" : "Carga media: {percentage}% ({load}) en el último minuto",
    "{lastMinutePercentage} % ({lastMinute}) last Minute\n{last5MinutesPercentage} % ({last5Minutes}) last 5 Minutes\n{last15MinutesPercentage} % ({last15Minutes}) last 15 Minutes" : "{lastMinutePercentage}% ({lastMinute}) último minuto\n{last5MinutesPercentage}% ({last5Minutes}) últimos 5 minutos \n{last15MinutesPercentage}% ({last15Minutes}) últimos 15 minutos",
    "RAM Usage:" : "Uso de RAM:",
    "SWAP Usage:" : "Uso de SWAP:",
    "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}" : "RAM: Total: {memTotalBytes} / Uso actual: {memUsageBytes}",
    "RAM info not available" : "Los datos de la RAM no están disponibles",
    "SWAP: Total: {swapTotalBytes}/Current usage: {swapUsageBytes}" : "SWAP: Total: {swapTotalBytes} / Uso actual: {swapUsageBytes}",
    "SWAP info not available" : "Los datos de SWAP no están disponibles",
    "Copied!" : "¡Copiado!",
    "Not supported!" : "No está soportado.",
    "Press ⌘-C to copy." : "Pulsa ⌘-C para copiar.",
    "Press Ctrl-C to copy." : "Pulsa Ctrl-C para copiar.",
    "System" : "Sistema",
    "Monitoring" : "Monitorización",
    "Monitoring app with useful server information" : "App de monitorización con información útil sobre el servidor",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Provee información útil como la carga de la CPU, el uso de RAM y disco, el número de usuarios, etc.",
    "Operating System:" : "Sistema Operativo",
    "CPU:" : "CPU:",
    "Unknown Processor" : "Processor desconocido",
    "Memory:" : "Memoria",
    "Server time:" : "Hora del servidor",
    "Uptime:" : "Tiempo activo",
    "Temperature" : "Temperatura",
    "Load" : "Carga",
    "Memory" : "Memoria",
    "Disk" : "Disco",
    "Mount:" : "Montado",
    "Filesystem:" : "Sistema de archivos",
    "Size:" : "Tamaño:",
    "Available:" : "Disponible",
    "Used:" : "Usado",
    "Files:" : "Archivos:",
    "Storages:" : "Almacenamientos:",
    "Free Space:" : "Espacio libre:",
    "Network" : "Red",
    "Hostname:" : "Dirección del servidor",
    "Gateway:" : "Puerta de acceso",
    "Status:" : "Estado",
    "Speed:" : "Velocidad",
    "Duplex:" : "Dúplex:",
    "MAC:" : "MAC:",
    "IPv4:" : "IPv4:",
    "IPv6:" : "IPv6:",
    "Active users" : "Usuarios activos",
    "Last hour" : "Última hora",
    "%s%% of all users" : "%s%% de todos los usuarios",
    "Last 24 Hours" : "Últimas 24 horas",
    "Last 7 Days" : "Últimos 7 días",
    "Last 30 Days" : "Últimos 30 días",
    "Shares" : "Recursos compartidos",
    "Users:" : "Usuarios:",
    "Groups:" : "Grupos:",
    "Links:" : "Enlaces:",
    "Emails:" : "Correos:",
    "Federated sent:" : "Federaciones enviadas:",
    "Federated received:" : "Federaciones recibidas:",
    "Talk conversations:" : "Conversaciones de Talk:",
    "PHP" : "PHP",
    "Version:" : "Versión:",
    "Memory limit:" : "Límite de memoria",
    "Max execution time:" : "Tiempo máx. de ejecución",
    "Upload max size:" : "Tamaño máximo de subida:",
    "OPcache Revalidate Frequency:" : "Frecuencia de Revalidación de OPcache:",
    "Extensions:" : "Extensiones:",
    "Unable to list extensions" : "No se pueden listar las extensiones",
    "Show phpinfo" : "Mostrar phpinfo",
    "Database" : "Base de datos",
    "Type:" : "Tipo:",
    "External monitoring tool" : "Herramienta externa de monitorización",
    "Use this end point to connect an external monitoring tool:" : "Utilice este endpoint para conectar una herramienta de monitoreo externa.",
    "Copy" : "Copiar",
    "Output in JSON" : "Salida en JSON",
    "Skip apps section (including apps section will send an external request to the app store)" : "Omitir la sección de aplicaciones (al incluirla, se enviarán peticiones externas a la tienda de aplicaciones)",
    "Skip server update" : "Omitir actualización del servidor",
    "To use an access token, please generate one then set it using the following command:" : "Para usar un token de acceso, por favor, genere uno y luego establézcalo usando el siguiente comando",
    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "Luego pase el token con el encabezado \"NC-Token\" cuando solicite la URL anterior.",
    "Load average: {cpu} (last minute)" : "Carga media: {cpu} (último minuto)",
    "DNS:" : "DNS:",
    "Total users:" : "Usuarios totales:",
    "24 hours:" : "24 horas:",
    "1 hour:" : "1 hora:",
    "5 mins:" : "5 mins:"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-32.0.3-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/serverinfo/l10n/es.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "Información de CPU no disponible",
    "CPU Usage:" : "Uso de CPU:",
    "Load average: {percentage} % ({load}) last minute" : "Carga promedio: {percentage}% ({load}) en el último minuto",
    "{lastMinutePercentage} % ({lastMinute}) last Minute\n{last5MinutesPercentage} % ({last5Minutes}) last 5 Minutes\n{last15MinutesPercentage} % ({last15Minutes}) last 15 Minutes" : "{lastMinutePercentage}% ({lastMinute}) último minuto\n{last5MinutesPercentage}% ({last5Minutes}) últimos 5 minutos \n{last15MinutesPercentage}% ({last15Minutes}) últimos 15 minutos",
    "RAM Usage:" : "Uso de RAM:",
    "SWAP Usage:" : "Uso de SWAP:",
    "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}" : "RAM: Total: {memTotalBytes} / Uso actual: {memUsageBytes}",
    "RAM info not available" : "Los datos de la RAM no están disponibles",
    "SWAP: Total: {swapTotalBytes}/Current usage: {swapUsageBytes}" : "SWAP: Total: {swapTotalBytes} / Uso actual: {swapUsageBytes}",
    "SWAP info not available" : "La información sobre el SWAP no está disponible",
    "Copied!" : "¡Copiado!",
    "Not supported!" : "No está soportado.",
    "Press ⌘-C to copy." : "Pulsa ⌘-C para copiar.",
    "Press Ctrl-C to copy." : "Pulsa Ctrl-C para copiar.",
    "System" : "Sistema",
    "Monitoring" : "Monitorización",
    "Monitoring app with useful server information" : "App de monitorización con información útil sobre el servidor",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Provee información útil como la carga de la CPU, el uso de RAM y disco, el número de usuarios, etc.",
    "Operating System:" : "Sistema Operativo:",
    "CPU:" : "CPU:",
    "threads" : "hilos",
    "Memory:" : "Memoria",
    "Server time:" : "Hora del servidor:",
    "Uptime:" : "Tiempo de actividad:",
    "Temperature" : "Temperatura",
    "Load" : "Carga",
    "Memory" : "Memoria",
    "Disk" : "Disco",
    "Mount:" : "Punto de montaje:",
    "Filesystem:" : "Sistema de archivos:",
    "Size:" : "Tamaño:",
    "Available:" : "Disponible:",
    "Used:" : "Usado:",
    "Files:" : "Archivos:",
    "Storages:" : "Almacenamientos:",
    "Free Space:" : "Espacio libre:",
    "Network" : "Red",
    "Hostname:" : "Nombre del servidor:",
    "Gateway:" : "Puerta de enlace:",
    "Status:" : "Estado:",
    "Speed:" : "Velocidad:",
    "Duplex:" : "Dúplex:",
    "MAC:" : "MAC:",
    "IPv4:" : "IPv4:",
    "IPv6:" : "IPv6:",
    "Active users" : "Usuarios activos",
    "Last hour" : "Última hora",
    "%s%% of all users" : "%s%% de todos los usuarios",
    "Last 24 Hours" : "Últimas 24 horas",
    "Last 7 Days" : "Últimos 7 días",
    "Last 30 Days" : "Últimos 30 días",
    "Shares" : "Recursos compartidos",
    "Users:" : "Usuarios:",
    "Groups:" : "Grupos:",
    "Links:" : "Enlaces:",
    "Emails:" : "Correos:",
    "Federated sent:" : "Federaciones enviadas:",
    "Federated received:" : "Federaciones recibidas:",
    "Talk conversations:" : "Conversaciones de Talk:",
    "PHP" : "PHP",
    "Version:" : "Versión:",
    "Memory limit:" : "Límite de memoria:",
    "Max execution time:" : "Tiempo máx. de ejecución:",
    "Upload max size:" : "Tamaño máx. de subida:",
    "OPcache Revalidate Frequency:" : "Frecuencia de Revalidación de OPcache:",
    "Extensions:" : "Extensiones:",
    "Unable to list extensions" : "No se pueden listar las extensiones",
    "Show phpinfo" : "Mostrar phpinfo",
    "FPM worker pool" : "Pool de workers FPM",
    "Pool name:" : "Nombre del pool:",
    "Pool type:" : "Tipo del Pool:",
    "Start time:" : "Hora de inicio:",
    "Accepted connections:" : "Conexiones aceptadas:",
    "Total processes:" : "Total de procesos:",
    "Active processes:" : "Procesos activos:",
    "Idle processes:" : "Procesos ociosos:",
    "Listen queue:" : "Cola de atención:",
    "Slow requests:" : "Solicitudes lentas:",
    "Max listen queue:" : "Cola de atención máx.:",
    "Max active processes:" : "Número máx. de procesos activos:",
    "Max children reached:" : "Número máx. de procesos heredados alcanzados:",
    "Database" : "Base de datos",
    "Type:" : "Tipo:",
    "External monitoring tool" : "Herramienta externa de monitorización",
    "Use this end point to connect an external monitoring tool:" : "Utilice este endpoint para conectar una herramienta de monitoreo externa.",
    "Copy" : "Copiar",
    "Output in JSON" : "Salida en JSON",
    "Skip apps section (including apps section will send an external request to the app store)" : "Omitir la sección de aplicaciones (al incluirla, se enviarán solicitudes externas a la tienda de aplicaciones)",
    "Skip server update" : "Omitir actualización del servidor",
    "To use an access token, please generate one then set it using the following command:" : "Para usar un token de acceso, por favor, genere uno y luego establezca el mismo usando el siguiente comando:",
    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "Luego pase el token con el encabezado \"NC-Token\" cuando solicite la URL anterior.",
    "Unknown Processor" : "Processor desconocido"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
